@@ -120,6 +120,125 @@
 #  network_stats_wrapper function 
 
 ################################################################################
+
+#Type codes are as follows (where (i,j) is the focal edge):
+#
+#  UTP - Undirected two-path (undirected graphs only)
+#  OTP - Outgoing two-path (i->k->j)
+#  ITP - Incoming two-path (i<-k<-j)
+#  RTP - Reciprocated two-path (i<->k<->j)
+#  OSP - Outgoing shared partner (i->k<-j)
+#  ISP - Incoming shared partner (i<-k->j)
+#
+# The default, OTP, retains the original behavior of dsp/gwdsp.  If
+# and only if the network is undirected, the UTP routine is used
+# (since it is safe for undirected graphs), irrespective of the user's
+# selection.
+#
+
+SPTYPE_DESC <- c(UTP = "undirected two-path",
+                 OTP = "outgoing two-path",
+                 ITP = "incoming two-path",
+                 RTP = "reciprocated two-path",
+                 OSP = "outgoing shared partner",
+                 ISP = "incoming shared partner")
+
+SPTYPE_CODE <- c(UTP = 0L, OTP = 1L, ITP = 2L, RTP = 3L, OSP = 4L, ISP = 5L)
+
+.d_sp_resolve_type <- function(nw, a, undname, bip){
+  type <- toupper(a$type[1])
+
+  ## Deal with cases for which network type determines term SP type:
+  if(is.bipartite(nw) && nchar(bip)) type <- c(b1="OSP", b2="ISP")[bip]
+  else if(!is.directed(nw)) type <- "UTP"
+
+  ## Check that the ultimate result is valid:
+  if(! type%in%names(SPTYPE_CODE))
+    ergm_Init_abort("Illegal value for ", sQuote("type"), "; valid types are:", paste.and(sQuote(names(SPTYPE_CODE))))
+
+  type
+}
+
+.d_sp_impl <- function(sp, nw, arglist, cache.sp, emptynwstats = function(...)NULL, ...){
+  if(sp %in% c("b1","b2")){
+    bip <- sp
+    sp <- "d"
+  }else bip <- ""
+
+  a <- check.ErgmTerm(nw, arglist,
+                      varnames = c("d","type"),
+                      vartypes = c("numeric","character"),
+                      defaultvalues = list(NULL,"OTP"),
+                      required = c(TRUE, FALSE))
+  utermname <- paste0(bip, sp, "sp")
+
+  d<-a$d
+  ld<-length(d)
+  if(ld==0) return(NULL)
+
+  type <- .d_sp_resolve_type(nw, a, utermname, bip)
+  conam <- if(type=="UTP" || nchar(bip)) utermname else paste0(utermname,".",type)
+
+  list(name=if(nchar(bip)) "ddspbwrap" else paste0("d",utermname), coef.names=paste(conam,d,sep=""), iinputs=c(SPTYPE_CODE[type],d),
+       minval=0, emptynwstats=emptynwstats(nw=nw, a=a, d=d, type=type),
+       auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
+}
+
+.dgw_sp_impl <- function(sp, nw, arglist, cache.sp, gw.cutoff, ...){
+  if(sp %in% c("b1","b2")){
+    bip <- sp
+    sp <- "d"
+  }else bip <- ""
+
+  a <- check.ErgmTerm(nw, arglist,
+                      varnames = c("decay","fixed","cutoff","type", "alpha"),
+                      vartypes = c("numeric","logical","numeric","character", "numeric"),
+                      defaultvalues = list(NULL, FALSE, gw.cutoff,"OTP", NULL),
+                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE))
+  utermname <- paste0("gw",bip,sp,"sp")
+  termname <- paste0("dgw",bip,sp,"sp")
+
+  decay_vs_fixed(a, termname)
+  decay<-a$decay;fixed<-a$fixed
+  cutoff<-a$cutoff
+  decay=decay[1] # Not sure why anyone would enter a vector here, but...
+
+  type <- .d_sp_resolve_type(nw, a, utermname, bip)
+  statname <- if(type=="UTP" || nchar(bip)) utermname else paste(utermname,type,sep=".")
+
+  if(!fixed){ # This is a curved exponential family model
+    maxsp <- min(cutoff, if(bip=="b1") network.size(nw)-nw%n%"bipartite"
+                          else if(bip=="b2") nw%n%"bipartite"
+                          else network.size(nw)-2)
+    if(maxsp==0) return(NULL)
+    d <- seq_len(maxsp)
+
+    params <- setNames(list(NULL,decay), c(statname,paste(statname,"decay",sep=".")))
+
+    c(list(name=if(nchar(bip)) "ddspdistbwrap" else paste0("d",sp,"spdist"),
+           coef.names=if(type=="UTP" || nchar(bip)) paste0(bip,sp,"sp#",d) else paste0(bip,sp,"sp.",type,"#",d),
+           cutoff.message = ergm_cutoff_message(maxsp, termname, sprintf("number of %ss on some %s", SPTYPE_DESC[type], c(e="edge", d="dyad", n="nonedge")[sp]), "cutoff", "gw.cutoff"),
+           iinputs=SPTYPE_CODE[type], params=params, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL), GWDECAY)
+  }else{
+    coef.names <- paste(statname,"fixed",decay,sep=".")
+    list(name=if(nchar(bip)) "dgwdspbwrap" else termname, coef.names=coef.names, inputs=decay, iinputs=SPTYPE_CODE[type], auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
+  }
+}
+
+.dsp_emptynwstats <- function(nw, d, ...){
+  if(any(d==0)){
+    emptynwstats <- numeric(length(d))
+    if(is.bipartite(nw)){
+      nb1 <- nw %n% "bipartite"
+      nb2 <- network.size(nw) - nb1
+      emptynwstats[d==0] <- nb1*(nb1-1)/2 + nb2*(nb2-1)/2
+    }else{
+      emptynwstats[d==0] <- network.dyadcount(nw,FALSE)
+    }
+    emptynwstats
+  }
+}
+
 #Term to count ESP statistics, where the shared partners may be any of
 #several distinct types.
 #
@@ -137,7 +256,7 @@
 #routine is used (since it is safe for undirected graphs), irrespective of
 #the user's selection.  UTP cannot be chosen otherwise, since it won't work.
 
-#' @templateVar name desp
+#' @templateVar name esp
 #' @title Directed edgewise shared partners
 #' @description This term adds one network statistic to the model for each element in `d` where the \eqn{i} th such statistic equals the number of edges in the network with exactly `d[i]` shared partners.
 #'   
@@ -155,34 +274,9 @@
 #' @template ergmTerm-sp-types
 #'
 #' @concept directed
+#' @aliases desp-ergmTerm
 InitErgmTerm.desp<-function(nw, arglist, cache.sp=TRUE, ...) {
-  a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("d","type"),
-                      vartypes = c("numeric","character"),
-                      defaultvalues = list(NULL,"OTP"),
-                      required = c(TRUE, FALSE))
-  d<-a$d
-  ld<-length(d)
-  if(ld==0){return(NULL)}
-  
-  type<-toupper(a$type[1])
-  type.vec<-c("OTP","ITP","RTP","OSP","ISP")
-  if(!(type%in%type.vec))
-    ergm_Init_abort("Illegal type code for esp; valid types are:",paste(type.vec, collapse=","))
-  dname<-"esp"
-  if(is.directed(nw)){
-    conam <- paste("esp",type,sep=".")
-    typecode<-which(type==type.vec)
-    dname <- "desp"
-  }else{
-    ergm_Init_inform("Use the ergm term 'esp' for undirected networks.")
-    dname <- "desp"
-    conam<-"esp"
-    type<-"UTP"
-    typecode<-0
-  }
-
-  list(name=dname, coef.names=paste(conam,d,sep=""), inputs=c(typecode,d), minval=0, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
+  .d_sp_impl("e", nw, arglist, cache.sp, ...)
 }
 
 
@@ -204,7 +298,7 @@ InitErgmTerm.desp<-function(nw, arglist, cache.sp=TRUE, ...) {
 #always used (since it is directedness-safe), and the user's input is
 #overridden.  UTP cannot be chosen otherwise, since it won't work.
 
-#' @templateVar name dgwesp
+#' @templateVar name gwesp
 #' @title Geometrically weighted edgewise shared partner distribution
 #' @description This term adds a statistic equal to the geometrically weighted edgewise (not dyadwise) shared partner distribution with decay parameter `decay` parameter.
 #'   
@@ -225,52 +319,9 @@ InitErgmTerm.desp<-function(nw, arglist, cache.sp=TRUE, ...) {
 #' @template ergmTerm-gw-alpha-to-decay
 #'
 #' @concept directed
+#' @aliases dgwesp-ergmTerm
 InitErgmTerm.dgwesp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
-  a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("decay","fixed","cutoff","type", "alpha"),
-                      vartypes = c("numeric","logical","numeric","character", "numeric"),
-                      defaultvalues = list(NULL, FALSE, gw.cutoff,"OTP", NULL),
-                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE))
-  decay_vs_fixed(a, 'dgwesp')
-  decay<-a$decay;fixed<-a$fixed
-  cutoff<-a$cutoff
-  decay=decay[1] # Not sure why anyone would enter a vector here, but...
-  type<-toupper(a$type[1])
-  type.vec<-c("OTP","ITP","RTP","OSP","ISP")
-  if(!(type%in%type.vec))
-    ergm_Init_abort("Illegal type code for gwesp; valid types are:",paste(type.vec, collapse=","))
-  dname<-"desp"
-  if(!is.directed(nw)){  
-    ergm_Init_inform("Use the gwesp term for undirected networks.")
-    type <- "UTP"
-    typecode<-0
-    basenam<-paste("gwesp",sep=".")
-  }else{
-    typecode<-which(type==type.vec)
-    basenam<-paste("gwesp",type,sep=".")
-  }
-  
-  if(!fixed){ # This is a curved exponential family model
-    maxesp <- min(cutoff,network.size(nw)-2)
-    d <- 1:maxesp
-    ld<-length(d)
-    if(ld==0){return(NULL)}
-    params<-list(gwesp=NULL,gwesp.decay=decay)
-    names(params)<-c(basenam,paste(basenam,"decay",sep="."))
-
-    c(list(name=dname,
-           coef.names=if(is.directed(nw)) paste("esp.",type,"#",d,sep="") else paste("esp#",d,sep=""), 
-           inputs=c(typecode,d), params=params, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL), GWDECAY)
-  }else{
-    dname<-"dgwesp"
-    maxesp <- min(cutoff,network.size(nw)-2)
-    if(is.directed(nw))
-      coef.names <- paste(paste("gwesp",type,"fixed.",sep="."),decay, sep="")
-    else
-      coef.names <- paste("gwesp.fixed.",decay,sep="")
-
-    list(name=dname, coef.names=coef.names, inputs=c(decay,typecode,maxesp), auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
-  }
+  .dgw_sp_impl("e", nw, arglist, cache.sp, gw.cutoff, ...)
 }
 
 
@@ -287,13 +338,9 @@ InitErgmTerm.dgwesp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
 #  OSP - Outgoing shared partner (i->k<-j)
 #  ISP - Incoming shared partner (i<-k->j)
 #
-#Only one type may be specified per dsp term.  The default, OTP, retains
-#the original behavior of dsp/gwdsp.  In the undirected case, the UTP
-#routine is used (since it is safe for undirected graphs), irrespective of
-#the user's selection.  UTP cannot be chosen otherwise, since it won't work.
-#
+#Only one type may be specified per dsp term.
 
-#' @templateVar name ddsp
+#' @templateVar name dsp
 #' @title Directed dyadwise shared partners
 #' @description This term adds one network statistic to the model for each element in `d` where the \eqn{i} th such statistic equals the number of dyads in the network with exactly `d[i]` shared partners.
 #'   
@@ -311,52 +358,16 @@ InitErgmTerm.dgwesp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
 #' @template ergmTerm-sp-types
 #'
 #' @concept directed
+#' @aliases ddsp-ergmTerm
 InitErgmTerm.ddsp<-function(nw, arglist, cache.sp=TRUE, ...) {
-  a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("d","type"),
-                      vartypes = c("numeric","character"),
-                      defaultvalues = list(NULL,"OTP"),
-                      required = c(TRUE, FALSE))
-  d<-a$d
-  ld<-length(d)
-  if(ld==0){return(NULL)}
-  
-  type<-toupper(a$type[1])
-  type.vec<-c("OTP","ITP","RTP","OSP","ISP")
-  if(!(type%in%type.vec))
-    ergm_Init_abort("Illegal type code for sp; valid types are:",paste(type.vec, collapse=","))
-  dname<-"ddsp"
-  if(is.directed(nw)){
-    conam <- paste("dsp",type,sep=".")
-    typecode<-which(type==type.vec)
-  }else{
-    ergm_Init_inform("Use the ergm term 'dsp' for undirected networks.")
-    conam<-"dsp"
-    type<-"UTP"
-    typecode<-0
-  }
-
-  if (any(d==0)) {
-    emptynwstats <- rep(0, length(d))
-    if(is.bipartite(nw)){
-      nb1 <- get.network.attribute(nw, "bipartite")
-      nb2 <- network.size(nw) - nb1
-      emptynwstats[d==0] <- nb1*(nb1-1)/2 + nb2*(nb2-1)/2
-    }else{
-      emptynwstats[d==0] <- network.dyadcount(nw,FALSE)
-    }
-  }else{
-    emptynwstats <- NULL
-  }
-  
-  list(name=dname, coef.names=paste(conam,d,sep=""), inputs=c(typecode,d), minval=0, emptynwstats=emptynwstats, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
+  .d_sp_impl("d", nw, arglist, cache.sp, emptynwstats=.dsp_emptynwstats, ...)
 }
 
 
 
 ################################################################################
 
-#' @templateVar name dgwdsp
+#' @templateVar name gwdsp
 #' @title Geometrically weighted dyadwise shared partner distribution
 #' @description This term adds one network statistic to the model equal to the geometrically weighted dyadwise shared partner distribution with decay parameter `decay` parameter.
 #'   
@@ -379,56 +390,9 @@ InitErgmTerm.ddsp<-function(nw, arglist, cache.sp=TRUE, ...) {
 #' @template ergmTerm-gw-alpha-to-decay
 #'
 #' @concept directed
+#' @aliases dgwdsp-ergmTerm
 InitErgmTerm.dgwdsp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
-  a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("decay","fixed","cutoff","type", "alpha"),
-                      vartypes = c("numeric","logical","numeric","character", "numeric"),
-                      defaultvalues = list(NULL, FALSE, gw.cutoff,"OTP", NULL),
-                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE))
-  decay_vs_fixed(a, 'dgwdsp')
-  decay<-a$decay;fixed<-a$fixed
-  cutoff<-a$cutoff
-  decay=decay[1] # Not sure why anyone would enter a vector here, but...
-  
-  type<-toupper(a$type[1])
-  type.vec<-c("OTP","ITP","RTP","OSP","ISP")
-  if(!(type%in%type.vec))
-    ergm_Init_abort("Illegal type code; valid types are:",paste(type.vec, collapse=","))
-  dname<-"ddsp"
-  
-  if(!is.directed(nw)){  
-    ergm_Init_inform("Use the gwdsp term for undirected networks.")
-    type <- "UTP"
-    basenam<-"gwdsp"
-    typecode<-0
-  }else{
-    typecode<-which(type==type.vec)
-    basenam<-paste("gwdsp",type,sep=".")
-  }
-
-  if(!fixed){ # This is a curved exponential family model
-    maxesp <- min(cutoff,network.size(nw)-2)
-    d <- 1:maxesp
-    ld<-length(d)
-    if(ld==0){return(NULL)}
-    
-    params<-list(gwdsp=NULL,gwdsp.decay=decay)
-    names(params)<-c(basenam,paste(basenam,"decay",sep="."))
-    
-    c(list(name=dname,
-           coef.names=if(is.directed(nw)) paste("dsp.",type,"#",d,sep="") else paste("dsp#",d,sep=""), 
-           inputs=c(typecode,d), params=params, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL),
-      GWDECAY)
-  }else{
-    dname<-"dgwdsp"
-    maxesp <- min(cutoff,network.size(nw)-2)
-    if (is.directed(nw)) 
-      coef.names <- paste("gwdsp",type,"fixed",decay,sep=".")
-    else
-      coef.names <- paste("gwdsp.fixed",decay,sep=".")
-    
-    list(name=dname, coef.names=coef.names, inputs=c(decay,typecode,maxesp), auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
-  }
+  .dgw_sp_impl("d", nw, arglist, cache.sp, gw.cutoff, ...)
 }
 
 
@@ -450,7 +414,7 @@ InitErgmTerm.dgwdsp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
 #the user's selection.  UTP cannot be chosen otherwise, since it won't work.
 #
 
-#' @templateVar name dnsp
+#' @templateVar name nsp
 #' @title Directed non-edgewise shared partners
 #' @description This term adds one network statistic to the model for each element in `d` where the \eqn{i} th such statistic equals the number of non-edges in the network with exactly `d[i]` shared partners.
 #'   
@@ -468,51 +432,15 @@ InitErgmTerm.dgwdsp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
 #' @template ergmTerm-sp-types
 #'
 #' @concept directed
+#' @aliases dnsp-ergmTerm
 InitErgmTerm.dnsp<-function(nw, arglist, cache.sp=TRUE, ...) {
-  a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("d","type"),
-                      vartypes = c("numeric","character"),
-                      defaultvalues = list(NULL,"OTP"),
-                      required = c(TRUE, FALSE))
-  d<-a$d
-  ld<-length(d)
-  if(ld==0){return(NULL)}
-  
-  type<-toupper(a$type[1])
-  type.vec<-c("OTP","ITP","RTP","OSP","ISP")
-  if(!(type%in%type.vec))
-    ergm_Init_abort("Illegal type code for sp; valid types are:",paste(type.vec, collapse=","))
-  dname<-"dnsp"
-  if(is.directed(nw)){
-    conam <- paste("nsp",type,sep=".")
-    typecode<-which(type==type.vec)
-  }else{
-    ergm_Init_inform("Use the ergm term 'nsp' for undirected networks.")
-    conam<-"nsp"
-    type<-"UTP"
-    typecode<-0
-  }
-
-  if (any(d==0)) {
-    emptynwstats <- rep(0, length(d))
-    if(is.bipartite(nw)){
-      nb1 <- get.network.attribute(nw, "bipartite")
-      nb2 <- network.size(nw) - nb1
-      emptynwstats[d==0] <- nb1*(nb1-1)/2 + nb2*(nb2-1)/2
-    }else{
-      emptynwstats[d==0] <- network.dyadcount(nw,FALSE)
-    }
-  }else{
-    emptynwstats <- NULL
-  }
-  
-  list(name=dname, coef.names=paste(conam,d,sep=""), inputs=c(typecode,d), minval=0, emptynwstats=emptynwstats, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
+  .d_sp_impl("n", nw, arglist, cache.sp, emptynwstats=.dsp_emptynwstats, ...)
 }
 
 
 ################################################################################
 
-#' @templateVar name dgwnsp
+#' @templateVar name gwnsp
 #' @title Geometrically weighted non-edgewise shared partner distribution
 #' @description This term is just like gwesp and gwdsp except it adds a statistic equal to the geometrically weighted nonedgewise (that is, over dyads that do not have an edge) shared partner distribution with decay parameter `decay` parameter.
 #'   
@@ -532,54 +460,45 @@ InitErgmTerm.dnsp<-function(nw, arglist, cache.sp=TRUE, ...) {
 #' @template ergmTerm-gw-alpha-to-decay
 #'
 #' @concept directed
+#' @aliases dgwnsp-ergmTerm
 InitErgmTerm.dgwnsp<-function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
-  a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("decay","fixed","cutoff","type", "alpha"),
-                      vartypes = c("numeric","logical","numeric","character", "numeric"),
-                      defaultvalues = list(NULL, FALSE, gw.cutoff,"OTP", NULL),
-                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE))
-  decay_vs_fixed(a, 'dgwnsp')
-  decay<-a$decay;fixed<-a$fixed
-  cutoff<-a$cutoff
-  decay=decay[1] # Not sure why anyone would enter a vector here, but...
-  
-  type<-toupper(a$type[1])
-  type.vec<-c("OTP","ITP","RTP","OSP","ISP")
-  if(!(type%in%type.vec))
-    ergm_Init_abort("Illegal type code; valid types are:",paste(type.vec, collapse=","))
-  dname<-"dnsp"
-  
-  if(!is.directed(nw)){  
-    ergm_Init_inform("Use the gwnsp term for undirected networks.")
-    type <- "UTP"
-    basenam<-"gwdsp"
-    typecode<-0
-  }else{
-    typecode<-which(type==type.vec)
-    basenam<-paste("gwnsp",type,sep=".")
-  }
-  
-  if(!fixed){ # This is a curved exponential family model
-    maxesp <- min(cutoff,network.size(nw)-2)
-    d <- 1:maxesp
-    ld<-length(d)
-    if(ld==0){return(NULL)}
-    
-    params<-list(gwnsp=NULL,gwnsp.decay=decay)
-    names(params)<-c(basenam,paste(basenam,"decay",sep="."))
-    
-    c(list(name=dname,
-           coef.names=if(is.directed(nw)) paste("nsp.",type,"#",d,sep="") else paste("nsp#",d,sep=""), 
-           
-           inputs=c(typecode,d), params=params, auxiliaries=if(cache.sp) .spcache.aux(type) else NULL),GWDECAY)
-  }else{
-    dname<-"dgwnsp"
-    maxesp <- min(cutoff,network.size(nw)-2)
-    if (is.directed(nw)) 
-      coef.names <- paste("gwnsp",type,"fixed",decay,sep=".")
-    else
-      coef.names <- paste("gwnsp.fixed",decay,sep=".")
-    
-    list(name=dname, coef.names=coef.names, inputs=c(decay,typecode,maxesp), auxiliaries=if(cache.sp) .spcache.aux(type) else NULL)
-  }
+  .dgw_sp_impl("n", nw, arglist, cache.sp, gw.cutoff, ...)
 }
+
+################################################################################
+
+#' @templateVar name gwnsp
+#' @template ergmTerm-rdname
+#' @usage
+#' # binary: gwnsp(decay, fixed=FALSE, cutoff=30, type="OTP")
+InitErgmTerm.gwnsp <- InitErgmTerm.dgwnsp
+
+#' @templateVar name gwdsp
+#' @template ergmTerm-rdname
+#' @usage
+#' # binary: gwdsp(decay, fixed=FALSE, cutoff=30, type="OTP")
+InitErgmTerm.gwdsp <- InitErgmTerm.dgwdsp
+
+#' @templateVar name gwesp
+#' @template ergmTerm-rdname
+#' @usage
+#' # binary: gwesp(decay, fixed=FALSE, cutoff=30, type="OTP")
+InitErgmTerm.gwesp <- InitErgmTerm.dgwesp
+
+#' @templateVar name dsp
+#' @template ergmTerm-rdname
+#' @usage
+#' # binary: dsp(d, type="OTP")
+InitErgmTerm.dsp <- InitErgmTerm.ddsp
+
+#' @templateVar name esp
+#' @template ergmTerm-rdname
+#' @usage
+#' # binary: esp(d, type="OTP")
+InitErgmTerm.esp <- InitErgmTerm.desp
+
+#' @templateVar name nsp
+#' @template ergmTerm-rdname
+#' @usage
+#' # binary: nsp(d, type="OTP")
+InitErgmTerm.nsp <- InitErgmTerm.dnsp
