@@ -111,7 +111,7 @@ logLik.ergm<-function(object, add=FALSE, force.reeval=FALSE, eval.loglik=add ||
     ## If dyad-dependent but not valued and has a dyad-independent constraint, bridge from a dyad-independent model.
     else if(is.dyad.independent(object, "space")
             && !is.valued(object))
-      ergm.bridge.dindstart.llk(formula,reference=reference,constraints=constraints,obs.constraints=obs.constraints,coef=coef(object),target.stats=object$target.stats,control=control.bridge,llkonly=FALSE,...,verbose=verbose)
+      ergm.bridge.dindstart.llk(formula,reference=reference,constraints=constraints,obs.constraints=obs.constraints,coef=coef(object),target.stats=object$target.stats,control=control.bridge,llkonly=FALSE,basis=object$network,...,verbose=verbose)
     ## If valued or has dyad-dependent constraint, bridge from the null model (reference measure).
     else
       ergm.bridge.0.llk(formula,reference=reference,constraints=constraints,obs.constraints=obs.constraints,coef=coef(object),target.stats=object$target.stats,control=control.bridge,llkonly=FALSE,basis=object$network,...,verbose=verbose)
@@ -201,10 +201,9 @@ nobs.ergm <- function(object, ...){
     warning("The number of observed dyads in this network is ill-defined due to complex constraints on the sample space. Disable this warning with ",sQuote("options(ergm.loglik.warn_dyads=FALSE)"),".")
   }
 
-  # TODO: Remove the as.rlebdm() approach at the same time as as.rlebdm.ergm().
   NVL3(NVL(object$mple.null.lik, object$mple.lik, object$null.lik, object$mle.lik),
        attr(.,"nobs"),
-       NVL(object$info$n_info_dyads, sum(as.rlebdm(object, which="informative"))))
+       object$info$n_info_dyads)
 }
 
 NO_NULL_IMPLICATION <- "This means that all likelihood-based inference (LRT, Analysis of Deviance, AIC, BIC, etc.) is only valid between models with the same reference distribution and constraints."
