@@ -17,7 +17,7 @@ C_CHANGESTAT_FN(c_concurrent_ties) {
   int echange;
   Vertex taildeg, headdeg;
 
-    echange = IS_OUTEDGE(tail, head) ? -1 : 1;
+    echange = edgestate ? -1 : 1;
     taildeg = OUT_DEG[tail];
     headdeg = IN_DEG[head];
     if(!DIRECTED){
@@ -46,7 +46,7 @@ C_CHANGESTAT_FN(c_concurrent_ties_by_attr) {
   int j, echange, tailattr, headattr;
   Vertex taildeg, headdeg;
 
-    echange = IS_OUTEDGE(tail, head) ? -1 : 1;
+    echange = edgestate ? -1 : 1;
     taildeg = OUT_DEG[tail];
     headdeg = IN_DEG[head];
     if(!DIRECTED){
