@@ -5,7 +5,7 @@
  *  open source, and has the attribution requirements (GPL Section 7) at
  *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2022 Statnet Commons
+ *  Copyright 2003-2023 Statnet Commons
  */
 #include "ergm_wtedgetree.h"
 #include "ergm_Rutil.h"
@@ -285,7 +285,7 @@ void Wtprintedge(Edge e, WtTreeNode *edges){
   Rprintf("\t.parent=%d\n",edges[e].parent);
   Rprintf("\t.left=%d\n",edges[e].left);
   Rprintf("\t.right=%d\n",edges[e].right);
-  Rprintf("\t.weight=%d\n",edges[e].weight);
+  Rprintf("\t.weight=%f\n",edges[e].weight);
 }
 
 /*****************
